@@ -6,6 +6,8 @@ from sqlalchemy.orm import sessionmaker
 import transaction
 import zope.sqlalchemy
 
+from pyramid.i18n import get_localizer
+
 from pyramid.authorization import ACLAuthorizationPolicy
 from pyramid.authentication import SessionAuthenticationPolicy
 from .constants import Conf
@@ -60,9 +62,34 @@ def getLoggedUser(request,addinsession=False):
         #l.warn("**** session is:{}.\nI was looking for this key:{} -> {}".format(request.session,Conf.sessionuser,request.session.get(Conf.sessionuser,None)))
     return None
     
+
+def add_renderer_globals(event):
+    # ...
+    request = event['request']
+    event['_'] = request.translate
+    event['_p'] = request.pluralize
+    event['localizer'] = request.localizer
+
+#tsf = TranslationStringFactory('YOUR_GETTEXT_DOMAIN')
+from .ppss_auth_utils import _ as tsf
+
+def add_localizer(event):
+    request = event.request
+    localizer = get_localizer(request)
+    defaultdomain = tsf('ppss_auth').domain
+    def auto_translate(*args, **kwargs):
+        return localizer.translate(tsf(*args, **kwargs))
+    def auto_pluralize(src,num, *args,**kwargs):
+        thisdomain = kwargs['domain'] if 'domain' in kwargs else defaultdomain
+        return localizer.pluralize(tsf(src,*args, **kwargs),'',num,domain=thisdomain)
+    request.localizer = localizer
+    request.translate = auto_translate
+    request.pluralize = auto_pluralize
+
 def getPPSSAuthConf(request):
     return Conf
 
+
 configured = False
 def includeme(config):
     global configured
@@ -74,6 +101,14 @@ def includeme(config):
     settings = config.get_settings()
     Conf.setup(settings)
     config.add_request_method(getLoggedUser,'loggeduser',reify=True)
+    
+    config.add_translation_dirs('ppss_auth:locale/')
+
+    config.add_subscriber(add_renderer_globals,
+                          'pyramid.events.BeforeRender')
+    config.add_subscriber(add_localizer,
+                          'pyramid.events.NewRequest')
+
     config.add_request_method(getPPSSAuthConf,'ppssauthconf',reify=True)
     initAuthDb(settings)
 
