@@ -167,14 +167,15 @@ class AuthController():
                 res = PPSsuser.checkLogin(username,password,r.dbsession)
             if res:
                 res.getPermissionsMap()
-                if superuser:
-                    l.info("{username} logged in as superuser".format(username=username) )
-                    r.session['admin'] = True
-                    r.session['principals'] = ["g:admin","g:sysadmin"]
-                else:
-                    l.debug("{username} logged in as normal user".format(username=username) )
-                    r.session['principals'] = res.getPrincipals(res.passwordExpired()) 
-                    r.session['admin'] = False
+                self.setPrincipalsInSession(res,superuser,res.passwordExpired())
+                #if superuser:
+                #    l.info("{username} logged in as superuser".format(username=username) )
+                #    r.session['admin'] = True
+                #    r.session['principals'] = ["g:admin","g:sysadmin"]
+                #else:
+                #    l.debug("{username} logged in as normal user".format(username=username) )
+                #    r.session['principals'] = res.getPrincipals(res.passwordExpired()) 
+                #    r.session['admin'] = False
                 r.dbsession.expunge(res)
 
                 ## log the last login
@@ -256,8 +257,11 @@ class AuthController():
         if not Conf.sessionuser in self.request.session:
             return HTTPFound(self.request.route_url("ppsslogin"))
         message = ""
+        forcedtochange=False
         if self.user.passwordExpired():
+            #dead code here, message never used
             message = Conf.passwordexpiredmessage
+            forcedtochange=True
         
         retdict = {'logintpl': Conf.publictemplateinherit,'msg':message,'res':True}
         retdict.update(self.retdict)
@@ -279,20 +283,35 @@ class AuthController():
                     user.setPassword(newpassword)
                     retdict['msg'] = __(self.request,"Password updated.")
                     l.info("password upadated for user '{}'".format(user.username))
+                    if forcedtochange:
+                        #load permission for user forced to change password
+                        self.setPrincipalsInSession(user,user.isSuperUser(),False   )
                 else:
                     retdict['res']=False
                     retdict['msg'] = res.getMsg(self.request)
                     #__(self.request,"New password doesn't match constraints." )
                     l.info("password upadated failed for user '{}'".format(user.username))
-
-                
-                
-                #TODO: execute fake login with post login redirect?
             else:
                 retdict['res']=False
-                retdict['msg']=__('Old password is wrong')
+                retdict['msg']=__(self.request,'Old password is wrong')
         return retdict
         
+    def setPrincipalsInSession(self,user,isSuperUser=None,passwordExpired=None):
+        if isSuperUser  is None:
+            isSuperUser = user.isSuperUser()
+        if passwordExpired is None:
+            passwordExpired  = user.passwordExpired()
+        r = self.request
+        if isSuperUser:
+            r.session['admin'] = True
+            r.session['principals'] = ["g:admin","g:sysadmin"]
+        else:
+            r.session['principals'] = user.getPrincipals(passwordExpired) 
+            r.session['admin'] = False
+        l.info("permissions for {}({},{}):{}".format(user.username,isSuperUser,passwordExpired,r.session['principals'])  )
+        r.session.changed()
+
+
     def listUser(self):
         elements = self.request.dbsession.query(PPSsuser).all()
         retdict = {'elements':elements}
